@@ -1,4 +1,4 @@
-from typing import TYPE_CHECKING, Union
+from typing import TYPE_CHECKING, Union, List
 
 from django.core.mail import EmailMessage
 from django.forms import ALL_FIELDS
@@ -11,7 +11,7 @@ if TYPE_CHECKING:
 
 def send_model_mail(
     obj: "Model",
-    to: list[str],
+    to: List[str],
     subject: str,
     fields: Union[str, list[str]] = ALL_FIELDS,
     template_name: str = "model_mail/email.html",
